@@ -53,7 +53,7 @@ class AdaptIntentSkill(Skill):
             entity_value=payload['entity_value']
         )
 
-        for alias in payload.get('entity_values', []):
+        for alias in payload.get('entity_aliases', []):
             self.engine.register_entity(
                 entity_type=payload['entity_type'],
                 entity_value=alias,
